#
# spec file for package cdi-api
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedreltag .NOTHING
%global namedversion %{version}%{?namedreltag}
%bcond_with tests
%bcond_without asciidoc
Name:           cdi-api
Version:        1.2
Release:        5.1
Summary:        Contexts and Dependency Injection for Java EE
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://seamframework.org/Weld
Source0:        https://github.com/cdi-spec/cdi/archive/%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  glassfish-el-api
BuildRequires:  javapackages-local
BuildRequires:  jboss-interceptors-1.2-api
Requires:       mvn(javax.el:javax.el-api)
Requires:       mvn(javax.inject:javax.inject)
Requires:       mvn(org.jboss.spec.javax.interceptor:jboss-interceptors-api_1.2_spec)
BuildArch:      noarch
%if %{with asciidoc}
BuildRequires:  asciidoc
BuildRequires:  python3-Pygments
%endif

%description
APIs for JSR-299: Contexts and Dependency Injection for Java EE

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n cdi-%{version}
cp %{SOURCE1} api/build.xml

# Use newer version of interceptors API
%pom_change_dep "javax.interceptor:javax.interceptor-api" "org.jboss.spec.javax.interceptor:jboss-interceptors-api_1.2_spec" api

%pom_remove_parent api

%build
mkdir -p lib
build-jar-repository -s lib glassfish-el-api jboss-interceptors-1.2-api javax.inject
pushd api
  %{ant} \
  %if %{without tests}
    -Dtest.skip=true \
  %endif
    jar javadoc
popd

%if %{with asciidoc}
cd spec/src/main/doc
asciidoc -n -b html5 -a toc2 -a toclevels=3 -a pygments -f html5.conf -o cdi-spec.html cdi-spec.asciidoc
asciidoc -n -b html5 -a toc2 -a toclevels=3 -a pygments -f html5.conf -o license-asl2.html license-asl2.asciidoc
asciidoc -n -b html5 -a toc2 -a toclevels=3 -a pygments -f html5.conf -o license-jcp.html license-jcp.asciidoc
%global adoc html
%else
%global adoc asciidoc
%endif

%install
pushd api
  # jar
  install -dm 0755 %{buildroot}%{_javadir}/%{name}
  install -dm 0755 %{buildroot}%{_javadir}/javax.enterprise.inject
  install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
  ln -sf ../%{name}/%{name}.jar %{buildroot}%{_javadir}/javax.enterprise.inject/%{name}.jar
  # pom
  install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
  install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
  %add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
  # javadoc
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
  cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
  %fdupes -s %{buildroot}%{_javadocdir}
popd

%files -f api/.mfiles
%doc spec/src/main/doc/cdi-spec.%{adoc}
%license spec/src/main/doc/license-asl2.%{adoc}
%license spec/src/main/doc/license-jcp.%{adoc}
%{_javadir}/javax.enterprise.inject

%files javadoc
%license spec/src/main/doc/license-asl2.%{adoc}
%license spec/src/main/doc/license-jcp.%{adoc}
%{_javadocdir}/%{name}

%changelog
* Wed Mar 27 2019 Jan Engelhardt <jengelh@inai.de>
- Replace summary by something that speaks more than two
  acronyms.
* Wed Mar 27 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of cdi-api 1.2
- Generate and customize the ant build.xml file
